@@ -5,8 +5,19 @@ Style sheets reference
 
 This script demonstrates the different available style sheets on a
 common set of example plots: scatter plot, image, bar graph, patches,
-line plot and histogram,
+line plot and histogram.
 
+Any of these style sheets can be imported (i.e. activated) by its name.
+For example for the ggplot style:
+
+>>> plt.style.use('ggplot')
+
+The names of the available style sheets can be found
+in the list `matplotlib.style.available`
+(they are also printed in the corner of each plot below).
+
+See more details in :ref:`Customizing Matplotlib
+using style sheets<customizing-with-style-sheets>`.
 """
 
 import numpy as np
@@ -116,7 +127,7 @@ def plot_figure(style_label=""):
     prng = np.random.RandomState(96917002)
 
     fig, axs = plt.subplots(ncols=6, nrows=1, num=style_label,
-                            figsize=(14.8, 2.8), constrained_layout=True)
+                            figsize=(14.8, 2.8), layout='constrained')
 
     # make a suptitle, in the same style for all subfigures,
     # except those with dark backgrounds, which get a lighter color:
