@@ -1,7 +1,7 @@
 """
-=========================
-Embedding In GTK3 Panzoom
-=========================
+===========================================
+Embedding in GTK3 with a navigation toolbar
+===========================================
 
 Demonstrate NavigationToolbar with GTK3 accessed via pygobject.
 """
@@ -20,23 +20,23 @@ import numpy as np
 win = Gtk.Window()
 win.connect("delete-event", Gtk.main_quit)
 win.set_default_size(400, 300)
-win.set_title("Embedding in GTK")
+win.set_title("Embedding in GTK3")
 
-f = Figure(figsize=(5, 4), dpi=100)
-a = f.add_subplot(1, 1, 1)
+fig = Figure(figsize=(5, 4), dpi=100)
+ax = fig.add_subplot(1, 1, 1)
 t = np.arange(0.0, 3.0, 0.01)
 s = np.sin(2*np.pi*t)
-a.plot(t, s)
+ax.plot(t, s)
 
 vbox = Gtk.VBox()
 win.add(vbox)
 
 # Add canvas to vbox
-canvas = FigureCanvas(f)  # a Gtk.DrawingArea
+canvas = FigureCanvas(fig)  # a Gtk.DrawingArea
 vbox.pack_start(canvas, True, True, 0)
 
 # Create toolbar
-toolbar = NavigationToolbar(canvas, win)
+toolbar = NavigationToolbar(canvas)
 vbox.pack_start(toolbar, False, False, 0)
 
 win.show_all()
