@@ -15,6 +15,7 @@ import matplotlib.pyplot as plt
 from matplotlib.testing.decorators import check_figures_equal, image_comparison
 from matplotlib.testing._markers import needs_usetex
 from matplotlib import font_manager as fm
+from matplotlib.offsetbox import (OffsetImage, AnnotationBbox)
 
 
 def test_visibility():
@@ -122,6 +123,27 @@ def test_rasterized_ordering(fig_test, fig_ref):
     ax_test.plot(x+1, y, "-", c="b", lw=10, rasterized=False, zorder=1.2)
 
 
+@check_figures_equal(tol=5, extensions=['svg', 'pdf'])
+def test_prevent_rasterization(fig_test, fig_ref):
+    loc = [0.05, 0.05]
+
+    ax_ref = fig_ref.subplots()
+
+    ax_ref.plot([loc[0]], [loc[1]], marker="x", c="black", zorder=2)
+
+    b = mpl.offsetbox.TextArea("X")
+    abox = mpl.offsetbox.AnnotationBbox(b, loc, zorder=2.1)
+    ax_ref.add_artist(abox)
+
+    ax_test = fig_test.subplots()
+    ax_test.plot([loc[0]], [loc[1]], marker="x", c="black", zorder=2,
+                 rasterized=True)
+
+    b = mpl.offsetbox.TextArea("X")
+    abox = mpl.offsetbox.AnnotationBbox(b, loc, zorder=2.1)
+    ax_test.add_artist(abox)
+
+
 def test_count_bitmaps():
     def count_tag(fig, tag):
         with BytesIO() as fd:
@@ -527,3 +549,95 @@ def test_svg_escape():
         fig.savefig(fd, format='svg')
         buf = fd.getvalue().decode()
         assert '&lt;&apos;&quot;&amp;&gt;"' in buf
+
+
+@pytest.mark.parametrize("font_str", [
+    "'DejaVu Sans', 'WenQuanYi Zen Hei', 'Arial', sans-serif",
+    "'DejaVu Serif', 'WenQuanYi Zen Hei', 'Times New Roman', serif",
+    "'Arial', 'WenQuanYi Zen Hei', cursive",
+    "'Impact', 'WenQuanYi Zen Hei', fantasy",
+    "'DejaVu Sans Mono', 'WenQuanYi Zen Hei', 'Courier New', monospace",
+    # These do not work because the logic to get the font metrics will not find
+    # WenQuanYi as the fallback logic stops with the first fallback font:
+    # "'DejaVu Sans Mono', 'Courier New', 'WenQuanYi Zen Hei', monospace",
+    # "'DejaVu Sans', 'Arial', 'WenQuanYi Zen Hei', sans-serif",
+    # "'DejaVu Serif', 'Times New Roman', 'WenQuanYi Zen Hei',  serif",
+])
+@pytest.mark.parametrize("include_generic", [True, False])
+def test_svg_font_string(font_str, include_generic):
+    fp = fm.FontProperties(family=["WenQuanYi Zen Hei"])
+    if Path(fm.findfont(fp)).name != "wqy-zenhei.ttc":
+        pytest.skip("Font may be missing")
+
+    explicit, *rest, generic = map(
+        lambda x: x.strip("'"), font_str.split(", ")
+    )
+    size = len(generic)
+    if include_generic:
+        rest = rest + [generic]
+    plt.rcParams[f"font.{generic}"] = rest
+    plt.rcParams["font.size"] = size
+    plt.rcParams["svg.fonttype"] = "none"
+
+    fig, ax = plt.subplots()
+    if generic == "sans-serif":
+        generic_options = ["sans", "sans-serif", "sans serif"]
+    else:
+        generic_options = [generic]
+
+    for generic_name in generic_options:
+        # test that fallback works
+        ax.text(0.5, 0.5, "There are 几个汉字 in between!",
+                family=[explicit, generic_name], ha="center")
+        # test deduplication works
+        ax.text(0.5, 0.1, "There are 几个汉字 in between!",
+                family=[explicit, *rest, generic_name], ha="center")
+    ax.axis("off")
+
+    with BytesIO() as fd:
+        fig.savefig(fd, format="svg")
+        buf = fd.getvalue()
+
+    tree = xml.etree.ElementTree.fromstring(buf)
+    ns = "http://www.w3.org/2000/svg"
+    text_count = 0
+    for text_element in tree.findall(f".//{{{ns}}}text"):
+        text_count += 1
+        font_info = dict(
+            map(lambda x: x.strip(), _.strip().split(":"))
+            for _ in dict(text_element.items())["style"].split(";")
+        )["font"]
+
+        assert font_info == f"{size}px {font_str}"
+    assert text_count == len(ax.texts)
+
+
+def test_annotationbbox_gid():
+    # Test that object gid appears in the AnnotationBbox
+    # in output svg.
+    fig = plt.figure()
+    ax = fig.add_subplot()
+    arr_img = np.ones((32, 32))
+    xy = (0.3, 0.55)
+
+    imagebox = OffsetImage(arr_img, zoom=0.1)
+    imagebox.image.axes = ax
+
+    ab = AnnotationBbox(imagebox, xy,
+                        xybox=(120., -80.),
+                        xycoords='data',
+                        boxcoords="offset points",
+                        pad=0.5,
+                        arrowprops=dict(
+                            arrowstyle="->",
+                            connectionstyle="angle,angleA=0,angleB=90,rad=3")
+                        )
+    ab.set_gid("a test for issue 20044")
+    ax.add_artist(ab)
+
+    with BytesIO() as fd:
+        fig.savefig(fd, format='svg')
+        buf = fd.getvalue().decode('utf-8')
+
+    expected = '<g id="a test for issue 20044">'
+    assert expected in buf
