@@ -231,13 +231,13 @@ bool load_tcl_tk(T lib)
 {
     // Try to fill Tcl/Tk global vars with function pointers.  Return whether
     // all of them have been filled.
-    if (void* ptr = dlsym(lib, "Tcl_SetVar")) {
+    if (auto ptr = dlsym(lib, "Tcl_SetVar")) {
         TCL_SETVAR = (Tcl_SetVar_t)ptr;
     }
-    if (void* ptr = dlsym(lib, "Tk_FindPhoto")) {
+    if (auto ptr = dlsym(lib, "Tk_FindPhoto")) {
         TK_FIND_PHOTO = (Tk_FindPhoto_t)ptr;
     }
-    if (void* ptr = dlsym(lib, "Tk_PhotoPutBlock")) {
+    if (auto ptr = dlsym(lib, "Tk_PhotoPutBlock")) {
         TK_PHOTO_PUT_BLOCK = (Tk_PhotoPutBlock_t)ptr;
     }
     return TCL_SETVAR && TK_FIND_PHOTO && TK_PHOTO_PUT_BLOCK;
@@ -324,11 +324,16 @@ void load_tkinter_funcs(void)
 
 exit:
     // We don't need to keep a reference open as the main program & tkinter
-    // have been imported.  Use a non-short-circuiting "or" to try closing both
-    // handles before handling errors.
-    if ((main_program && dlclose(main_program))
-        | (tkinter_lib && dlclose(tkinter_lib))) {
+    // have been imported.  Try to close each library separately (otherwise the
+    // second dlclose could clear a dlerror from the first dlclose).
+    bool raised_dlerror = false;
+    if (main_program && dlclose(main_program) && !raised_dlerror) {
         PyErr_SetString(PyExc_RuntimeError, dlerror());
+        raised_dlerror = true;
+    }
+    if (tkinter_lib && dlclose(tkinter_lib) && !raised_dlerror) {
+        PyErr_SetString(PyExc_RuntimeError, dlerror());
+        raised_dlerror = true;
     }
     Py_XDECREF(module);
     Py_XDECREF(py_path);
